summaryrefslogtreecommitdiff
path: root/Build/source/libs/libpng/png.h
diff options
context:
space:
mode:
Diffstat (limited to 'Build/source/libs/libpng/png.h')
-rw-r--r--Build/source/libs/libpng/png.h42
1 files changed, 30 insertions, 12 deletions
diff --git a/Build/source/libs/libpng/png.h b/Build/source/libs/libpng/png.h
index 6e538552cb5..2e194b7a3d9 100644
--- a/Build/source/libs/libpng/png.h
+++ b/Build/source/libs/libpng/png.h
@@ -1,7 +1,6 @@
-
/* png.h - header file for PNG reference library
*
* libpng version 1.2.25 - February 18, 2008
* Copyright (c) 1998-2008 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +8,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.2.25 - February 18, 2008: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -177,6 +176,22 @@
* 1.2.24 13 10224 12.so.0.24[.0]
* 1.2.25beta01-06 13 10225 12.so.0.25[.0]
* 1.2.25rc01-02 13 10225 12.so.0.25[.0]
+ * 1.0.31 10 10031 10.so.0.31[.0]
+ * 1.2.25 13 10225 12.so.0.25[.0]
+ * 1.2.26beta01-06 13 10226 12.so.0.26[.0]
+ * 1.2.26rc01 13 10226 12.so.0.26[.0]
+ * 1.2.26 13 10226 12.so.0.26[.0]
+ * 1.0.32 10 10032 10.so.0.32[.0]
+ * 1.2.27beta01-06 13 10227 12.so.0.27[.0]
+ * 1.2.27rc01 13 10227 12.so.0.27[.0]
+ * 1.0.33 10 10033 10.so.0.33[.0]
+ * 1.2.27 13 10227 12.so.0.27[.0]
+ * 1.0.34 10 10034 10.so.0.34[.0]
+ * 1.2.28 13 10228 12.so.0.28[.0]
+ * 1.2.29beta01-03 13 10229 12.so.0.29[.0]
+ * 1.2.29rc01 13 10229 12.so.0.29[.0]
+ * 1.0.35 10 10035 10.so.0.35[.0]
+ * 1.2.29 13 10229 12.so.0.29[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -186,7 +201,7 @@
* to the source version x.y.z (leading zeros in y and z). Beta versions
* were given the previous public release number plus a letter, until
* version 1.0.6j; from then on they were given the upcoming public
- * release number plus "betaNN" or "rcN".
+ * release number plus "betaNN" or "rcNN".
*
* Binary incompatibility exists only when applications make direct access
* to the info_ptr or png_ptr members through png.h, and the compiled
@@ -206,7 +221,7 @@
* If you modify libpng you may insert additional notices immediately following
* this sentence.
*
* libpng versions 1.2.6, August 15, 2004, through 1.2.25, February 18, 2008, are
* Copyright (c) 2004, 2006-2008 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -318,13 +333,13 @@
* Y2K compliance in libpng:
* =========================
*
- * February 18, 2008
+ * May 8, 2008
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.2.25 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -380,9 +395,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.25"
+#define PNG_LIBPNG_VER_STRING "1.2.29"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.2.25 - February 18, 2008\n"
+ " libpng version 1.2.29 - May 8, 2008\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 13
@@ -390,7 +405,7 @@
/* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
#define PNG_LIBPNG_VER_MAJOR 1
#define PNG_LIBPNG_VER_MINOR 2
-#define PNG_LIBPNG_VER_RELEASE 25
+#define PNG_LIBPNG_VER_RELEASE 29
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero: */
@@ -418,7 +433,7 @@
* Versions 0.7 through 1.0.0 were in the range 0 to 100 here (only
* version 1.0.0 was mis-numbered 100 instead of 10000). From
* version 1.0.1 it's xxyyzz, where x=major, y=minor, z=release */
-#define PNG_LIBPNG_VER 10225 /* 1.2.25 */
+#define PNG_LIBPNG_VER 10229 /* 1.2.29 */
#ifndef PNG_VERSION_INFO_ONLY
/* include the compression library's header */
@@ -1426,13 +1441,16 @@ struct png_struct_def
/* storage for unknown chunk that the library doesn't recognize. */
png_unknown_chunk unknown_chunk;
#endif
+
+/* New members added in libpng-1.2.26 */
+ png_uint_32 old_big_row_buf_size, old_prev_row_size;
};
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_2_25;
+typedef png_structp version_1_2_29;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,6 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.2.25 - February 18, 2008
+ * libpng version 1.2.29 - May 8, 2008
* Copyright (c) 1998-2008 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +8,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.2.25 - February 18, 2008: Glenn
+ * libpng versions 0.97, January 1998, through 1.2.29 - May 8, 2008: Glenn
* See also "Contributing Authors", below.
*
@@ -206,7 +221,7 @@
* this sentence.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.2.25, February 18, 2008, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.2.29, May 8, 2008, are
* Copyright (c) 2004, 2006-2008 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -318,13 +333,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.2.25 are Y2K compliant. It is my belief that earlier
+ * upward through 1.2.29 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*